@@ -40,7 +40,7 @@ def save_config(node, force=False):
     if no nodes/hostname.json exists, or force=True, it creates one
     it also saves to tmp_node.json
     """
-    filepath = os.path.join("nodes/", env.host_string + ".json")
+    filepath = os.path.join("nodes", env.host_string + ".json")
     tmp_filename = 'tmp_{0}.json'.format(env.host_string)
     files_to_create = [tmp_filename]
     if not os.path.exists(filepath) or force:
@@ -69,6 +69,9 @@ def sync_node(node):
     It also injects the ipaddress to the node's config file if not already
     existent.
     """
+    if node.get('dummy'):
+        lib.print_header("Skipping dummy: {0}".format(env.host))
+        return
     # Get merged attributes
     current_node = _build_node_data_bag()
     with lib.credentials():
