@@ -48,10 +48,10 @@ def get_node(name):
 
 def get_nodes(environment=None):
     """Gets all nodes found in the nodes/ directory"""
-    if not os.path.exists('nodes/'):
+    if not os.path.exists('nodes'):
         return []
     nodes = []
-    for filename in sorted([f for f in os.listdir('nodes/')
+    for filename in sorted([f for f in os.listdir('nodes')
                                 if not os.path.isdir(f) and f.endswith(".json")
                                     and not f.startswith('.')]):
         fqdn = ".".join(filename.split('.')[:-1])  # Remove .json from name
@@ -133,7 +133,7 @@ def print_nodes(nodes, detailed=False):
     for node in nodes:
         found += 1
         print_node(node, detailed=detailed)
-    print("\nFound {0} node{1}".format(found, "s" if found > 1 else ""))
+    print("\nFound {0} node{1}".format(found, "s" if found != 1 else ""))
 
 
 def _generate_metadata(path, cookbook_path, name):
@@ -144,12 +144,12 @@ def _generate_metadata(path, cookbook_path, name):
     metadata_path_rb = os.path.join(path, 'metadata.rb')
     metadata_path_json = os.path.join(path, 'metadata.json')
     if (os.path.exists(metadata_path_rb) and
-        (not os.path.exists(metadata_path_json) or
-         os.stat(metadata_path_rb).st_mtime > \
-         os.stat(metadata_path_json).st_mtime)):
+            (not os.path.exists(metadata_path_json) or
+            os.stat(metadata_path_rb).st_mtime > \
+            os.stat(metadata_path_json).st_mtime)):
         error_msg = "Warning: metadata.json for {0}".format(name)
         error_msg += " in {0} is older that metadata.rb".format(cookbook_path)
-        error_msg += ", and cookbook attributes could be out of date\n"
+        error_msg += ", cookbook attributes could be out of date\n\n"
         try:
             proc = subprocess.Popen(
                 ['knife', 'cookbook', 'metadata', '-o', cookbook_path, name],
@@ -167,16 +167,16 @@ def _generate_metadata(path, cookbook_path, name):
                 error_msg += "while executing knife to generate "
                 error_msg += "metadata.json for {0}".format(path)
                 print(error_msg)
-                if env.loglevel == 'debug':
-                    print "\n".join(resp.split("\n")[:2])
-            else:
-                print("Generated metadata.json for {0}".format(path))
+                print resp
+            if env.loglevel == 'debug':
+                print "\n".join(resp.split("\n")[:2])
         except OSError:
             knife_installed = False
             error_msg += "If you locally install Chef's knife tool, LittleChef"
-            error_msg += " will regenerate metadata.json files automatically"
+            error_msg += " will regenerate metadata.json files automatically\n"
             print(error_msg)
-
+        else:
+            print("Generated metadata.json for {0}\n".format(path))
 
 def get_recipes_in_cookbook(name):
     """Gets the name of all recipes present in a cookbook
@@ -204,7 +204,7 @@ def get_recipes_in_cookbook(name):
                     cookbook = json.loads(f.read())
                 except json.JSONDecodeError as e:
                     msg = "Little Chef found the following error in your"
-                    msg += " {0}.json file:\n  {1}".format(
+                    msg += " {0} file:\n  {1}".format(
                         os.path.join(path, 'metadata.json'), e)
                     abort(msg)
                 # Add each recipe defined in the cookbook
@@ -314,7 +314,7 @@ def get_roles_in_node(node):
 
 def _get_role(rolename):
     """Reads and parses a file containing a role"""
-    path = 'roles/' + rolename + '.json'
+    path = os.path.join('roles', rolename + '.json')
     if not os.path.exists(path):
         abort("Couldn't read role file {0}".format(path))
     with open(path, 'r') as f:
@@ -329,13 +329,13 @@ def _get_role(rolename):
 
 
 def get_roles():
-    """Gets all roles found in the roles/ directory"""
+    """Gets all roles found in the 'roles' directory"""
     roles = []
-    for root, subfolders, files in os.walk('roles/'):
+    for root, subfolders, files in os.walk('roles'):
         for filename in files:
             if filename.endswith(".json"):
                 path = os.path.join(
-                    root[len('roles/'):], filename[:-len('.json')])
+                    root[len('roles'):], filename[:-len('.json')])
                 roles.append(_get_role(path))
     return sorted(roles, key=lambda x: x['fullname'])
 
@@ -366,8 +366,8 @@ def print_plugin_list():
 
 def get_plugins():
     """Gets available plugins by looking into the plugins/ directory"""
-    if os.path.exists('plugins/'):
-        for filename in sorted([f for f in os.listdir('plugins/')
+    if os.path.exists('plugins'):
+        for filename in sorted([f for f in os.listdir('plugins')
                 if not os.path.isdir(f) and f.endswith(".py")]):
             plugin_name = filename[:-3]
             try:
