@@ -124,14 +124,11 @@ def node(*nodes):
             env.host = hostname
             env.host_string = hostname
             node = lib.get_node(env.host)
-            if node.get('dummy'):
-                lib.print_header("Skipping dummy: {0}".format(env.host))
+            lib.print_header("Configuring {0}".format(env.host))
+            if __testing__:
+                print "TEST: would now configure {0}".format(env.host)
             else:
-                lib.print_header("Configuring {0}".format(env.host))
-                if __testing__:
-                    print "TEST: would now configure {0}".format(env.host)
-                else:
-                    chef.sync_node(node)
+                chef.sync_node(node)
 
 
 def deploy_chef(gems="no", ask="yes", version="0.10",
@@ -215,9 +212,11 @@ def ssh(name):
     # Execute remotely using either the sudo or the run fabric functions
     with settings(hide("warnings"), warn_only=True):
         if name.startswith("sudo "):
-            sudo(name[5:])
+            with lib.credentials():
+                sudo(name[5:])
         else:
-            run(name)
+            with lib.credentials():
+                run(name)
 
 
 def plugin(name):
