@@ -90,9 +90,15 @@ def configure(current_node=None):
             'environment': current_node.get('chef_environment', '_default'),
             'verbose': "true" if env.verbose else "false"
         }
-        with hide('running', 'stdout'):
-            upload_template(os.path.join(BASEDIR, 'solo.rb'), '/etc/chef/',
-                context=data, use_sudo=True, backup=False, mode=0400)
+        with settings(hide('everything')):
+            try:
+                upload_template(os.path.join(BASEDIR, 'solo.rb'), '/etc/chef/',
+                    context=data, use_sudo=True, backup=False, mode=0400)
+            except SystemExit:
+                error = ("Failed to upload '/etc/chef/solo.rb'\n"
+                "This can happen when the deployment user does not have a "
+                "home directory, which is needed as a temporary location")
+                abort(error)
         with hide('stdout'):
             sudo('chown root:root {0}'.format('/etc/chef/solo.rb'))
 
@@ -279,7 +285,7 @@ def _add_rpm_repos():
     with show('running'):
         # Install the EPEL Yum Repository.
         with settings(hide('warnings', 'running'), warn_only=True):
-            repo_url = "http://download.fedora.redhat.com"
+            repo_url = "http://dl.fedoraproject.org"
             repo_path = "/pub/epel/{0}/i386/".format(rhel_version)
             repo_path += "{0}.rpm".format(epel_release)
             output = sudo('rpm -Uvh {0}{1}'.format(repo_url, repo_path))
